==> neon_tts_plugin_coqui-0.4.1a6-py3-none-any.whl: neon_tts_plugin_coqui/configs.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

languages = {
    "en": {
        "model": "neongeckocom/tts-vits-ljspeech-en@v0.3", 
        "sentence": "A rainbow is a meteorological phenomenon that is caused by reflection, refraction and dispersion of light.",
    },
    "es": {
        "model": "neongeckocom/tts-vits-css10-es@v0.2", 
        "sentence": "Un arcoíris o arco iris es un fenómeno óptico y meteorológico que consiste en la aparición en el cielo de un arco de luz multicolor.",
    },
    "fr": {
        "model": "neongeckocom/tts-vits-css10-fr@v0.2", 
        "sentence": "Un arc-en-ciel est un photométéore, un phénomène optique se produisant dans le ciel, visible dans la direction opposée au Soleil.",
    },
    "de": {
        "model": "neongeckocom/tts-vits-css10-de@v0.2", 
        "sentence": "Der Regenbogen ist ein atmosphärisch-optisches Phänomen, das als kreisbogenförmiges farbiges Lichtband in einer von der Sonne.",
    },
    "pl": {
        "model": "neongeckocom/tts-vits-mai-pl@v0.6", 
        "sentence": "Tęcza, zjawisko optyczne i meteorologiczne, występujące w postaci charakterystycznego wielobarwnego łuku powstającego w wyniku rozszczepienia światła widzialnego.",
    },
    "uk": {
        "model": "neongeckocom/tts-vits-mai-uk@v0.9", 
        "sentence": "Веселка, також райдуга оптичне явище в атмосфері, що являє собою одну, дві чи декілька різнокольорових дуг, що спостерігаються на тлі хмари, якщо вона розташована проти Сонця.",
    },
    "nl": {
        "model": "neongeckocom/tts-vits-css10-nl@v0.2", 
        "sentence": "Een regenboog is een gekleurde cirkelboog die aan de hemel waargenomen kan worden als de, laagstaande.",
    },
    "hu": {
        "model": "neongeckocom/tts-vits-css10-hu@v0.1", 
        "sentence": "A szivárvány olyan optikai jelenség, melyet eső- vagy páracseppek okoznak, mikor a fény prizmaszerűen megtörik rajtuk és színeire bomlik.", 
    },
    "bg": {
        "model": "neongeckocom/tts-vits-cv-bg@v0.1", 
        "sentence": "Дъга е оптично и метеорологично явление, свързано с появата в небето на почти непрекъснат спектър на светлината.",
    },
    "fi": {
        "model": "neongeckocom/tts-vits-css10-fi@v0.1", 
        "sentence": "Sateenkaari on spektrin väreissä esiintyvä ilmakehän optinen ilmiö. Se syntyy, kun valo taittuu pisaran etupinnasta.",
    },
    "sl": {
        "model": "neongeckocom/tts-vits-cv-sl@v0.1", 
        "sentence": "Mavrica je svetlobni pojav v ozračju, ki ga vidimo v obliki loka spektralnih barv. Nastane zaradi loma, disperzije in odboja sončnih žarkov v vodnih kapljicah v zraku. Mavrica, ki nastane zaradi sončnih žarkov, se vedno pojavi na nasprotni strani od Sonca, tako da ima opazovalec Sonce vedno za hrbtom.",
    },
    "ga": {
        "model": "neongeckocom/tts-vits-cv-ga@v0.2", 
        "sentence": "Do réir lucht na heolaíochta, is é solas na gréine ag taitneamh ar bhraonta báistí sa spéir faoi ndearna an tuar ceatha. Dar linne ná tagann ón ngréin ach aon tsolais amháin, ach ní mar sin atá.",
    },
}

==> neon_tts_plugin_coqui-0.5.1a9-py3-none-any.whl: neon_tts_plugin_coqui/configs.py <==
# NEON AI (TM) SOFTWARE, Software Development Kit & Application Framework
# All trademark and other rights reserved by their respective owners
# Copyright 2008-2022 Neongecko.com Inc.
# Contributors: Daniel McKnight, Guy Daniels, Elon Gasper, Richard Leeds,
# Regina Bloomstine, Casimiro Ferreira, Andrii Pernatii, Kirill Hrymailo
# BSD-3 License
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 1. Redistributions of source code must retain the above copyright notice,
#    this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 3. Neither the name of the copyright holder nor the names of its
#    contributors may be used to endorse or promote products derived from this
#    software without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS  BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
# OR PROFITS;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE,  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

languages = {
    "en": {
        "model": "neongeckocom/tts-vits-ljspeech-en@v0.4", 
        "sentence": "A rainbow is a meteorological phenomenon that is caused by reflection, refraction and dispersion of light.",
    },
    "es": {
        "model": "neongeckocom/tts-vits-css10-es@v0.2", 
        "sentence": "Un arcoíris o arco iris es un fenómeno óptico y meteorológico que consiste en la aparición en el cielo de un arco de luz multicolor.",
    },
    "fr": {
        "model": "neongeckocom/tts-vits-css10-fr@v0.3", 
        "sentence": "Un arc-en-ciel est un photométéore, un phénomène optique se produisant dans le ciel, visible dans la direction opposée au Soleil.",
    },
    "de": {
        "model": "neongeckocom/tts-vits-css10-de@v0.2", 
        "sentence": "Der Regenbogen ist ein atmosphärisch-optisches Phänomen, das als kreisbogenförmiges farbiges Lichtband in einer von der Sonne.",
    },
    "it": {
        "model": "neongeckocom/tts-vits-cv-it@v0.1", 
        "sentence": "In fisica dell'atmosfera e meteorologia, l'arcobaleno è un fenomeno ottico atmosferico che produce uno spettro quasi continuo di luce nel cielo quando la luce del Sole attraversa le gocce d'acqua rimaste in sospensione dopo un temporale.",
    },
    "pl": {
        "model": "neongeckocom/tts-vits-mai-pl@v0.6", 
        "sentence": "Tęcza, zjawisko optyczne i meteorologiczne, występujące w postaci charakterystycznego wielobarwnego łuku powstającego w wyniku rozszczepienia światła widzialnego.",
    },
    "uk": {
        "model": "neongeckocom/tts-vits-mai-uk@v0.9", 
        "sentence": "Веселка, також райдуга оптичне явище в атмосфері, що являє собою одну, дві чи декілька різнокольорових дуг, що спостерігаються на тлі хмари, якщо вона розташована проти Сонця.",
    },
    "ro": {
        "model": "neongeckocom/tts-vits-cv-ro@v0.1", 
        "sentence": "Curcubeul este un fenomen optic și meteorologic atmosferic care se manifestă prin apariția pe cer a unui spectru de forma unui arc colorat atunci când lumina soarelui se refractă în picăturile de apă din atmosferă.", 
    },
    "hu": {
        "model": "neongeckocom/tts-vits-css10-hu@v0.1", 
        "sentence": "A szivárvány olyan optikai jelenség, melyet eső- vagy páracseppek okoznak, mikor a fény prizmaszerűen megtörik rajtuk és színeire bomlik.", 
    },
    "el": {
        "model": "neongeckocom/tts-vits-cv-el@v0.1", 
        "sentence": "Το ουράνιο τόξο εμφανίζεται όταν οι ακτίνες του ήλιου χτυπούν σταγόνες βροχής στην ατμόσφαιρα της Γης και είναι ένα παράδειγμα διάθλασης μετά την ανάκλαση.", 
    },
    "cs": {
        "model": "neongeckocom/tts-vits-cv-cs@v0.1", 
        "sentence": "Duha je fotometeor, projevující se jako skupina soustředných barevných oblouků, které vznikají lomem a vnitřním odrazem slunečního nebo měsíčního světla na vodních kapkách v atmosféře.", 
    },
    "sv": {
        "model": "neongeckocom/tts-vits-cv-sv@v0.1", 
        "sentence": "En regnbåge är ett optiskt, meteorologiskt fenomen som uppträder som ett fullständigt ljusspektrum i form av en båge på himlen då solen lyser på nedfallande regn. Klarast lyser regnbågen då halva himlen fortfarande är täckt med mörka moln som avger regn och betraktaren befinner sig under klar himmel.",
    },
    "bg": {
        "model": "neongeckocom/tts-vits-cv-bg@v0.1", 
        "sentence": "Дъга е оптично и метеорологично явление, свързано с появата в небето на почти непрекъснат спектър на светлината.",
    },
    "sk": {
        "model": "neongeckocom/tts-vits-cv-sk@v0.1", 
        "sentence": "Dúha je optický úkaz vznikajúci v atmosfére Zeme. Vznik dúhy je spôsobený disperziou slnečného svetla prechádzajúceho kvapkou.",
    },
    "nl": {
        "model": "neongeckocom/tts-vits-css10-nl@v0.2", 
        "sentence": "Een regenboog is een gekleurde cirkelboog die aan de hemel waargenomen kan worden als de, laagstaande.",
    },
    "fi": {
        "model": "neongeckocom/tts-vits-css10-fi@v0.1", 
        "sentence": "Sateenkaari on spektrin väreissä esiintyvä ilmakehän optinen ilmiö. Se syntyy, kun valo taittuu pisaran etupinnasta.",
    },
    "lt": {
        "model": "neongeckocom/tts-vits-cv-lt@v0.1", 
        "sentence": "Vaivorykštė - optinis ir meteorologinis reiškinys, kuomet Saulei apšvietus atmosferoje esančius vandens lašelius, danguje atsiranda ištisinė spalvų spektro juosta.",
    },
    "sl": {
        "model": "neongeckocom/tts-vits-cv-sl@v0.1", 
        "sentence": "Mavrica je svetlobni pojav v ozračju, ki ga vidimo v obliki loka spektralnih barv. Nastane zaradi loma, disperzije in odboja sončnih žarkov v vodnih kapljicah v zraku. Mavrica, ki nastane zaradi sončnih žarkov, se vedno pojavi na nasprotni strani od Sonca, tako da ima opazovalec Sonce vedno za hrbtom.",
    },
    "lv": {
        "model": "neongeckocom/tts-vits-cv-lv@v0.1", 
        "sentence": "Varavīksne ir optiska parādība atmosfērā, kuru rada Saules staru laušana un atstarošana krītošos lietus pilienos. Tā parādās iepretim Saulei uz mākoņu fona, kad līst. Varavīksnes loks pāri debesjumam ir viens no krāšņākajiem dabas skatiem. Pārējās krāsas izvietojušās atbilstoši tā loka gammai.",
    },
    "et": {
        "model": "neongeckocom/tts-vits-cv-et@v0.1", 
        "sentence": "Vikerkaare põhjustab päikesekiirte eri lainepikkustel erinev murdumine ja peegeldumine ligikaudu kerakujulistelt vihmapiiskadelt vihmaseinal või vihmapilves, kui päikesevalgus langeb piiskadele vaatleja selja tagant.",
    },
    "ga": {
        "model": "neongeckocom/tts-vits-cv-ga@v0.2", 
        "sentence": "Do réir lucht na heolaíochta, is é solas na gréine ag taitneamh ar bhraonta báistí sa spéir faoi ndearna an tuar ceatha. Dar linne ná tagann ón ngréin ach aon tsolais amháin, ach ní mar sin atá.",
    },
    "mt": {
        "model": "neongeckocom/tts-vits-cv-mt@v0.1", 
        "sentence": "Qawsalla hija fenomenu meteoroloġiku li huwa kkawżat minn riflessjoni, rifrazzjoni u tixrid ta 'dawl fi qtar ta' l-ilma li jirriżulta fi spettru ta 'dawl li jidher fis-sema.",
    },
}
